@@ -1,12 +1,12 @@
 # coding=utf8
 
-# Copyright 2018-2025 JDCLOUD.COM
+# Copyright 2018 JDCLOUD.COM
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#     http:#www.apache.org/licenses/LICENSE-2.0
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -34,5 +34,8 @@ SCHEME_HTTP = 'http'
 SCHEME_HTTPS = 'https'
 
 HEADER_REQUESTID = 'x-jdcloud-request-id'
+HEADER_CONTENT_LEN = 'Content-Length'
 HEADER_JCLOUD_PREFIX = 'x-jcloud'
-HEADER_JDCLOUD_PREFIX = 'x-jdcloud'
\ No newline at end of file
+HEADER_JDCLOUD_PREFIX = 'x-jdcloud'
+HEADER_ERROR = ('x-jcloud-pin', 'x-jcloud-erp', 'x-jcloud-security-token')
+HEADER_BASE64 = ('x-jdcloud-pin', 'x-jdcloud-erp', 'x-jdcloud-security-token')
